## dbt-snowflake 1.9.3 - April 29, 2025

### Breaking Changes

- Update `iceberg_managed` catalog type to `built_in` ([#1011](https://github.com/dbt-labs/dbt-adapters/issues/1011))

### Features

- Add support for Snowflake's managed Iceberg catalog via dbt's catalog framework ([#932](https://github.com/dbt-labs/dbt-adapters/issues/932))

### Fixes

- Correctly detect Iceberg tables when using multiple databases. ([#846](https://github.com/dbt-labs/dbt-adapters/issues/846))
- Dynamic table metadata queries now ignore the QUOTED_IDENTIFIERS_IGNORE_CASE setting ([#917](https://github.com/dbt-labs/dbt-adapters/issues/917))
- `datetime.datetime.utcnow()` is deprecated as of Python 3.12 ([#980](https://github.com/dbt-labs/dbt-adapters/issues/980))
- Fix regression in list_relations pagination that did not properly handle projects with more than 1,000 models ([#989](https://github.com/dbt-labs/dbt-adapters/issues/989))
- Pin certifi library to address regression in version 2025.4.26 ([#1027](https://github.com/dbt-labs/dbt-adapters/issues/1027))

### Under the Hood

- Simple fix to record/replay annotation. ([#761](https://github.com/dbt-labs/dbt-adapters/issues/761))
- Update list_relations_without_caching macro to reuse the same query on pagination and handle the quoted_identifiers_ignore_case setting ([#967](https://github.com/dbt-labs/dbt-adapters/issues/967))

### Contributors
- [@ms32035](https://github.com/ms32035) ([#846](https://github.com/dbt-labs/dbt-adapters/issues/846))
